==> libreoffice-l10n_4.2.7.orig.tar.xz: libreoffice-4.2.7/svx/source/form/sqlparserclient.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "sqlparserclient.hxx"
#include "svx/ParseContext.hxx"

//........................................................................
namespace svxform
{
//........................................................................

    using namespace ::com::sun::star::uno;
    using namespace ::com::sun::star::lang;

    //====================================================================
    //= OSQLParserClient
    //====================================================================
    //--------------------------------------------------------------------
    OSQLParserClient::OSQLParserClient(const Reference< XComponentContext >& rxContext)
    {
        m_xContext = rxContext;
    }
    //--------------------------------------------------------------------
    bool OSQLParserClient::ensureLoaded() const
    {
        if ( !ODbtoolsClient::ensureLoaded() )
            return false;
         m_xParser = getFactory()->createSQLParser(m_xContext,getParseContext());
        return m_xParser.is();
    }

//........................................................................
}   // namespace svxform
//........................................................................


/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-l10n_5.0.3~rc2.orig.tar.xz: libreoffice-5.0.3~rc2/svx/source/form/sqlparserclient.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "sqlparserclient.hxx"
#include "svx/ParseContext.hxx"

#include <connectivity/dbtools.hxx>
#include <connectivity/sqlparse.hxx>

using namespace ::dbtools;
using namespace ::connectivity;

namespace svxform
{
    using namespace ::com::sun::star::uno;
    using namespace ::com::sun::star::lang;

    OSQLParserClient::OSQLParserClient(const Reference< XComponentContext >& rxContext)
        : m_pParser(new OSQLParser(rxContext, getParseContext()))
    {
        m_xContext = rxContext;
    }

    std::shared_ptr< ::connectivity::OSQLParseNode > OSQLParserClient::predicateTree(
            OUString& _rErrorMessage,
            const OUString& _rStatement,
            const ::com::sun::star::uno::Reference< ::com::sun::star::util::XNumberFormatter >& _rxFormatter,
            const ::com::sun::star::uno::Reference< ::com::sun::star::beans::XPropertySet >& _rxField
        ) const
    {
        return std::shared_ptr< OSQLParseNode >(m_pParser->predicateTree(_rErrorMessage, _rStatement, _rxFormatter, _rxField));
    }

}



/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
